summaryrefslogtreecommitdiff
path: root/test/parallel/test-fs-readfile-error.js
diff options
context:
space:
mode:
Diffstat (limited to 'test/parallel/test-fs-readfile-error.js')
-rw-r--r--test/parallel/test-fs-readfile-error.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/parallel/test-fs-readfile-error.js b/test/parallel/test-fs-readfile-error.js
index fe6174c577..719c0061c4 100644
--- a/test/parallel/test-fs-readfile-error.js
+++ b/test/parallel/test-fs-readfile-error.js
@@ -25,9 +25,9 @@ const fs = require('fs');
// Test that fs.readFile fails correctly on a non-existent file.
-// `fs.readFile('/')` does not fail on FreeBSD, because you can open and read
-// the directory there.
-if (common.isFreeBSD)
+// `fs.readFile('/')` does not fail on AIX and FreeBSD because you can open
+// and read the directory there.
+if (common.isAIX || common.isFreeBSD)
common.skip('platform not supported.');
const assert = require('assert');